import React, { ReactNode } from "react";
import styles from "./MiniEventCard.module.css";

interface Props {
  name: string;
  descriptionShort: string;
  description: ReactNode;
  location: string;
  date: string;
  time: string;
}

const dropDownIcon = (
  <svg
    xmlns="http://www.w3.org/2000/svg"
    width="14"
    height="9"
    viewBox="0 0 14 9"
    fill="none"
    className={styles.dropDownIcon}
  >
    <path
      d="M6.24407 8.12713C6.64284 8.58759 7.35716 8.58759 7.75593 8.12713L13.3613 1.65465C13.9221 1.00701 13.4621 0 12.6053 0H1.39467C0.537918 0 0.0778675 1.00701 0.638743 1.65465L6.24407 8.12713Z"
      fill="#1482E3"
    />
  </svg>
);

export const MiniEventCard: React.FC<Props> = ({
  name,
  descriptionShort,
  description,
  location,
  date,
  time,
}) => {
  return (
    <details className={styles.miniEventCard}>
      <summary>
        <div onClick={(event) => event.preventDefault()}>
          <h2 className={styles.name}>
            <div>{name}</div>
            <div className={styles.nameSpacer}></div>
          </h2>
          <p className={styles.info}>
            {location} | {date} | {time}
          </p>
          <p className={styles.shortDescription}>{descriptionShort}</p>
        </div>

        <p className={styles.details}>View details {dropDownIcon}</p>
      </summary>

      <div>{description}</div>
    </details>
  );
};
